@@ -1,4 +1,4 @@
 __version__ = "0.1"
 user_agent = "rimudns/%s" % __version__
 rimu_base_url = 'https://rimuhosting.com'
-zonomi_base_url = 'https://https://zonomi.com/app'
\ No newline at end of file
+zonomi_base_url = 'https://zonomi.com/app'
\ No newline at end of file
